.. _matrix_inventory:

Pre-generated matrices
=======================

.. include:: pre_gen_warn.rst

The pages below contain all the **source and target gridspec** combinations for which a matrix is available. The information is grouped by source grid type.

.. toctree::
    :maxdepth: 1

    reduced_gg_o
    reduced_gg
    healpix_ring
    healpix_nested
    regular_ll
